@@ -11,12 +11,12 @@ use warnings::register;
 use attributes;
 
 use vars qw($VERSION $DATE $FILE);
-$VERSION = '1.21';
-$DATE = '2004/05/10';
+$VERSION = '1.26';
+$DATE = '2004/05/24';
 $FILE = __FILE__;
 
-use Data::SecsPack 0.04;
 use Data::Startup 0.02;
+use Data::Str2Num 0.05;
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1; # dump hashes sorted
 $Data::Dumper::Terse = 1; # avoid Varn Variables
@@ -47,17 +47,19 @@ sub new
        indent => '',
        version => $VERSION,
        warnings => 0,
-       'Data::SecsPack' => {}
    );
    $self->Data::Startup::override(@_);
 
 }
 
 
+######
+# WARNING: For some unknow reason that needs investigation
+# the use of SelfLoader causes massive failures, particular
+# in the regards to interface with SecsPack
+#
 # use SelfLoader;
-
 # 1
-
 # __DATA__
 
 
@@ -247,7 +249,7 @@ sub listify
                      }
                  }
                  if($is_numeric) {
-                     ($str, my @num) = Data::SecsPack->str2float(@{$var->[$i]}, {ascii_float => 1});
+                     ($str, my @num) = Data::Str2Num->str2float(@{$var->[$i]}, {ascii_float => 1});
                      if(@num != 0 && @$str == 0) {
                          push @secs_obj, 'N', \@num;
                          $i++;
@@ -316,7 +318,7 @@ sub listify
                      ######
                      # Try for a single packed number type
                      #
-                     ($str,my @num) = Data::SecsPack->str2float($var->[$i], {ascii_float => 1});
+                     ($str,my @num) = Data::Str2Num->str2float($var->[$i], {ascii_float => 1});
                      if(@num == 1 && @$str == 0) {
                          push @secs_obj, 'N', $num[0];
                      }
@@ -429,6 +431,7 @@ my @bin_format = (
 #
 sub neuterify
 {
+     require Data::SecsPack;
 
      ######
      # This subroutine uses no object data; therefore,
@@ -905,6 +908,7 @@ sub secs_elementify
          }
      }
      else {
+         require Data::SecsPack;
          if ($format =~ /[SUF]\d/ || $format eq 'T' || $format eq 'N') {
              my $number;
              $format = 'I' if $format eq 'N';
@@ -1067,7 +1071,7 @@ sub transify
               # Count the numbers, should agree with length 
               elsif ($format =~ /^[FNSTU]$/)  {
                   if(0 < $length) {
-                       ($str, my @nums) = Data::SecsPack->str2float($ascii_secs, {ascii_float => 1});
+                       ($str, my @nums) = Data::Str2Num->str2float($ascii_secs, {ascii_float => 1});
                        $ascii_secs = join ' ',@$str;
                        if($length != @nums) {
                            $event = "Wrong number of numbers." ;
@@ -1091,7 +1095,7 @@ sub transify
               ######
               # Count the numbers
               if( $format =~ /^[FNSTU]$/ ) {
-                  ($str, my @nums) = Data::SecsPack->str2float($ascii_secs, {ascii_float => 1});
+                  ($str, my @nums) = Data::Str2Num->str2float($ascii_secs, {ascii_float => 1});
                   $ascii_secs = join ' ',@$str;
                   push @secs_obj, "$format$byte_code";
                   if(@nums == 0) {
@@ -1313,7 +1317,7 @@ nested list between machines is SEMI E5-94.
 
 The L<Data::Secs2|Data::Secs2> program module
 facilitates the secsification of the nested data in accordance with 
-L<SEMI|http:E<sol>E<sol>www.semi.org>  E5-94,
+SEMI, http://www.semi.org,  E5-94,
 Semiconductor Equipment Communications Standard 2 (SECS-II),
 pronounced 'sex two' with gussto and a perverted smile. 
 The SEMI E4 SECS-I standard addresses transmitting SECSII messages from one machine to
@@ -1366,7 +1370,7 @@ Tony Blair not only SECS-II but SECS-I and High-Speed SECS.
 
 The nested data linear format used by the
 L<Data::Secs2|Data::Secs2> suroutines is in accordance with 
-L<SEMI|http:E<sol>E<sol>www.semi.org> E5-94,
+SEMI, http://www.semi.org, E5-94,
 Semiconductor Equipment Communications Standard 2 (SECS-II),
 pronounced 'sex two' with gussto and a perverted smile. 
 This industry standard is copyrighted and cannot be
@@ -2256,208 +2260,9 @@ follow on the next lines as comments. For example,
  my $test_data7 = 'a50150010541004105' . unpack('H*','ARRAY') . 
                   'a5034e2d19' .  'a90402000400' . 'b104000186a0';
 
- #######
- # multicell numberics, Perl Secs Object
- #
- my $test_data8 =
- 'U1[1] 80
- L[5]
-   A[0]
-   A[5] ARRAY
-   U1[3] 78 45 25
-   U2[2] 512 1024
-   U4[1] 100000
- ';
-
- #######
- # Strict Perl numberics, Perl Secs Object
- #
- my $test_data9 =
- 'U1[1] 80
- L[5]
-   A[0]
-   A[5] ARRAY
-   N[3] 78 45 25
-   N[2] 512 1024
-   N 100000
- ';
-
- my $test_data10 =
- 'U1[1] 80
- L[3]
-   A[0]
-   A[5] ARRAY
-   L[5]
-     A[0]
-     A[5] ARRAY
-     N 2
-     A[5] hello
-     N 4
- ';
-
- my $test_data11 =
- 'U1[1] 80
- L[3]
-   A[0]
-   A[5] ARRAY
-   L[6]
-     A[0]
-     A[4] HASH
-     A[4] body
-     A[5] hello
-     A[6] header
-     A[9] To: world
- ';
-
- my $test_data12 =
- 'U1[1] 80
- L[5]
-   A[0]
-   A[5] ARRAY
-   N 2
-   L[4]
-     A[0]
-     A[5] ARRAY
-     A[5] hello
-     A[5] world
-   N 512
- ';
-
- my $test_data13 =
- 'U1[1] 80
- L[4]
-   A[0]
-   A[5] ARRAY
-   N 2
-   L[6]
-     A[0]
-     A[4] HASH
-     A[6] header
-     L[6]
-       A[11] Class::None
-       A[4] HASH
-       A[4] From
-       A[6] nobody
-       A[2] To
-       A[6] nobody
-     A[3] msg
-     L[4]
-       A[0]
-       A[5] ARRAY
-       A[5] hello
-       A[5] world
- ';
-
- my $test_data14 =
- 'U1[1] 80
- L[4]
-   A[0]
-   A[5] ARRAY
-   L[6]
-     A[0]
-     A[4] HASH
-     A[6] header
-     L[6]
-       A[11] Class::None
-       A[4] HASH
-       A[4] From
-       A[6] nobody
-       A[2] To
-       A[6] nobody
-     A[3] msg
-     L[4]
-       A[0]
-       A[5] ARRAY
-       A[5] hello
-       A[5] world
-   L[6]
-     A[0]
-     A[4] HASH
-     A[6] header
-     L[3]
-       A[0]
-       A[5] Index
-       N 16
-     A[3] msg
-     L[3]
-       A[0]
-       A[5] ARRAY
-       A[4] body
- ';
-
- my $test_data15 =
- 'U1[1] 80
- U1[1] 2
- L[6]
-   A[0]
-   A[4] HASH
-   A[6] header
-   L[6]
-     A[11] Class::None
-     A[4] HASH
-     A[4] From
-     A[6] nobody
-     A[2] To
-     A[6] nobody
-   A[3] msg
-   L[4]
-     A[0]
-     A[5] ARRAY
-     A[5] hello
-     A[5] world
- ';
-
- my $test_data16 =
- 'U1[1] 80
- L[6]
-   A[0]
-   A[4] HASH
-   A[6] header
-   L[6]
-     A[11] Class::None
-     A[4] HASH
-     A[4] From
-     A[6] nobody
-     A[2] To
-     A[6] nobody
-   A[3] msg
-   L[4]
-     A[0]
-     A[5] ARRAY
-     A[5] hello
-     A[5] world
- L[6]
-   A[0]
-   A[4] HASH
-   A[6] header
-   L[3]
-     A[0]
-     A[5] Index
-     U1 10
-   A[3] msg
-   L[3]
-     A[0]
-     A[5] ARRAY
-     A[4] body
- ';
-
  my $test_data17 = 'a50150010541004105' . unpack('H*','ARRAY') . 
                   'a5034e2d19' .  'a90402000400' . 'b0000186a0';
 
- #######
- # multicell numberics, Perl Secs Object
- #
- my $test_data18 =
- 'U1[1] 80
- L[5]
-   A[0]
-   A[5] ARRAY
-   U1[3] 78 45 25
-   U2[2] 512 1024
-   U4 100000
- ';
-
-
  ##################
  # stringify an array
  # 
@@ -2492,15 +2297,17 @@ follow on the next lines as comments. For example,
  # ascii secsify lisfication of test_data1 an array reference
  # 
 
- secsify( listify( ['2', 'hello', 4] ) )
+ secsify( listify( ['2', 'hello', 4, 0, undef] ) )
 
  # 'U1[1] 80
- #L[5]
+ #L[7]
  #  A[0]
  #  A[5] ARRAY
  #  N 2
  #  A[5] hello
  #  N 4
+ #  N 0
+ #  L[0]
  #'
  #
 
@@ -2649,7 +2456,7 @@ follow on the next lines as comments. For example,
 
  unpack('H*',secsify( listify( ['2', 'hello', 4] ), {type => 'binary'}))
 
- # 'a501500105410041054152524159a50102410568656c6c6fa50104'
+ # '0101500105010001054152524159010102010568656c6c6f010104'
  #
 
  ##################
@@ -2658,7 +2465,7 @@ follow on the next lines as comments. For example,
 
  unpack('H*',secsify( listify( $test_data6 ), [type => 'binary']))
 
- # 'a501500105410041054152524159a5034e2d19a90402000400b104000186a0'
+ # '010150010501000105415252415901034e2d190104020004000104000186a0'
  #
 
  ##################
@@ -2667,7 +2474,7 @@ follow on the next lines as comments. For example,
 
  unpack('H*',secsify( listify( ['2', 'hello', 4] ), {type => 'binary', scalar => 1}))
 
- # 'a501500105410041054152524159a402410568656c6c6fa404'
+ # '01015001050100010541525241590002010568656c6c6f0004'
  #
 
  ##################
@@ -2676,7 +2483,7 @@ follow on the next lines as comments. For example,
 
  unpack('H*',secsify( listify( $test_data6 ), type => 'binary', scalar => 1))
 
- # 'a501500105410041054152524159a5034e2d19a90402000400b0000186a0'
+ # '010150010501000105415252415901034e2d1901040200040000000186a0'
  #
 
  ##################
@@ -2710,26 +2517,7 @@ follow on the next lines as comments. For example,
 
  secsify(neuterify (pack('H*',$big_secs2)))
 
- # 'U1[1] 80
- #U1[1] 2
- #L[6]
- #  A[0]
- #  A[4] HASH
- #  A[6] header
- #  L[6]
- #    A[11] Class::None
- #    A[4] HASH
- #    A[4] From
- #    A[6] nobody
- #    A[2] To
- #    A[6] nobody
- #  A[3] msg
- #  L[4]
- #    A[0]
- #    A[5] ARRAY
- #    A[5] hello
- #    A[5] world
- #'
+ # ''
  #
 
  ##################
@@ -2738,14 +2526,7 @@ follow on the next lines as comments. For example,
 
  secsify(neuterify (pack('H*',$test_data7)))
 
- # 'U1[1] 80
- #L[5]
- #  A[0]
- #  A[5] ARRAY
- #  U1[3] 78 45 25
- #  U2[2] 512 1024
- #  U4[1] 100000
- #'
+ # ''
  #
 
  ##################
@@ -2757,7 +2538,7 @@ follow on the next lines as comments. For example,
     while(chomp($event)) { };
  $event
 
- # 'Format byte length size field is zero.'
+ # 'Unknown SECSII format, '
  #
 
  ##################
@@ -2767,7 +2548,7 @@ follow on the next lines as comments. For example,
  $event = neuterify (pack('H*',$test_data17), scalar => 1)
  ref($event)
 
- # 'ARRAY'
+ # ''
  #
 
  ##################
@@ -2776,14 +2557,7 @@ follow on the next lines as comments. For example,
 
  secsify($event)
 
- # 'U1[1] 80
- #L[5]
- #  A[0]
- #  A[5] ARRAY
- #  U1[3] 78 45 25
- #  U2[2] 512 1024
- #  U4 100000
- #'
+ # ''
  #
 
  ##################
@@ -2890,7 +2664,6 @@ follow on the next lines as comments. For example,
  #          2,
  #          4
  #        ]
- #	Subroutine: Data::Secs2::transify 1.18
  #	ascii_secs:
  #	SECS object:
  #'L'
@@ -2903,6 +2676,7 @@ follow on the next lines as comments. For example,
  #''
  #'A'
  #'world'
+ #	Subroutine: Data::Secs2::transify 1.22
  #'
  #
 
@@ -3042,7 +2816,7 @@ distribution.
 
 =item 3
 
-The installation of the binary or source
+Commercial installation of the binary or source
 must visually present to the installer 
 the above copyright notice,
 this list of conditions intact,
@@ -3050,7 +2824,10 @@ that the original source is available
 at http://softwarediamonds.com
 and provide means
 for the installer to actively accept
-the list of conditions.
+the list of conditions; 
+otherwise, a license fee must be paid to
+Softwareware Diamonds.
+
 
 =back
 
@@ -3077,7 +2854,7 @@ ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =item L<Data::SecsPack|Data::SecsPack> 
 
-=item =item L<SEMI|http:E<sol>E<sol>www.semi.org>
+=item SEMI, http://www.semi.org,
 
 =item L<Docs::Site_SVD::Data_Secs2|Docs::Site_SVD::Data_Secs2>
 
