@@ -11,8 +11,8 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE);
-$VERSION = '1.17';
-$DATE = '2004/05/10';
+$VERSION = '1.18';
+$DATE = '2004/05/24';
 $FILE = __FILE__;
 
 use File::Spec;
@@ -550,7 +550,7 @@ distribution.
 
 =item 3
 
-The installation of the binary or source
+Commercial installation of the binary or source
 must visually present to the installer 
 the above copyright notice,
 this list of conditions intact,
@@ -558,7 +558,10 @@ that the original source is available
 at http://softwarediamonds.com
 and provide means
 for the installer to actively accept
-the list of conditions.
+the list of conditions; 
+otherwise, a license fee must be paid to
+Softwareware Diamonds.
+
 
 =back
 
